summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/addexistingfilesdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/addexistingfilesdlg.cpp')
-rw-r--r--buildtools/autotools/addexistingfilesdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/buildtools/autotools/addexistingfilesdlg.cpp b/buildtools/autotools/addexistingfilesdlg.cpp
index 519acb33..55533a3d 100644
--- a/buildtools/autotools/addexistingfilesdlg.cpp
+++ b/buildtools/autotools/addexistingfilesdlg.cpp
@@ -49,15 +49,15 @@
#include "addexistingfilesdlg.h"
/*
* Constructs a AddExistingFilesDialog which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddExistingFilesDialog::AddExistingFilesDialog ( AutoProjectPart* part, AutoProjectWidget *widget, SubprojectItem* spitem, TargetItem* titem, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : AddExistingDlgBase ( tqparent, name, modal, fl )
+AddExistingFilesDialog::AddExistingFilesDialog ( AutoProjectPart* part, AutoProjectWidget *widget, SubprojectItem* spitem, TargetItem* titem, TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : AddExistingDlgBase ( parent, name, modal, fl )
{
m_spitem = spitem;
m_titem = titem;
@@ -49,15 +49,15 @@
#include "addexistingfilesdlg.h"
/*
- * Constructs a AddExistingFilesDialog which is a child of 'tqparent', with the
+ * Constructs a AddExistingFilesDialog which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*